@@ -1,12 +1,10 @@
 #pragma once
 
-#ifndef FF_INCLUDED_detection_packages_packages
-#define FF_INCLUDED_detection_packages_packages
-
 #include "fastfetch.h"
 
 typedef struct FFPackagesResult
 {
+    uint32_t am;
     uint32_t apk;
     uint32_t brew;
     uint32_t brewCask;
@@ -19,12 +17,16 @@ typedef struct FFPackagesResult
     uint32_t nixDefault;
     uint32_t nixSystem;
     uint32_t nixUser;
+    uint32_t opkg;
     uint32_t pacman;
+    uint32_t paludis;
     uint32_t pkg;
-    uint32_t port;
+    uint32_t pkgtool;
+    uint32_t macports;
     uint32_t rpm;
     uint32_t scoop;
     uint32_t snap;
+    uint32_t winget;
     uint32_t xbps;
 
     uint32_t all; //Make sure this goes last
@@ -32,6 +34,4 @@ typedef struct FFPackagesResult
     FFstrbuf pacmanBranch;
 } FFPackagesResult;
 
-const FFPackagesResult* ffDetectPackages(const FFinstance* instance);
-
-#endif
+const char* ffDetectPackages(FFPackagesResult* result, FFPackagesOptions* options);
